django-recommends
======================================

A django app that builds item-based suggestions for users.

Documentation on `readthedocs <http://readthedocs.org/docs/django-recommends/en/latest/>`_.
